@@ -3,8 +3,9 @@ package telegram
 import (
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/testctx"
+	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -13,26 +14,54 @@ func TestStringer(t *testing.T) {
 }
 
 func TestDefault(t *testing.T) {
-	ctx := context.New(config.Project{})
+	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, ctx.Config.Announce.Telegram.MessageTemplate, defaultMessageTemplate)
 }
 
 func TestAnnounceInvalidTemplate(t *testing.T) {
-	ctx := context.New(config.Project{
-		Announce: config.Announce{
-			Telegram: config.Telegram{
-				MessageTemplate: "{{ .Foo }",
+	t.Run("message", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			Announce: config.Announce{
+				Telegram: config.Telegram{
+					MessageTemplate: "{{ .Foo }",
+				},
 			},
-		},
+		})
+		testlib.RequireTemplateError(t, Pipe{}.Announce(ctx))
+	})
+	t.Run("chatid", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			Announce: config.Announce{
+				Telegram: config.Telegram{
+					MessageTemplate: "test",
+					ChatID:          "{{ .Foo }",
+				},
+			},
+		})
+		testlib.RequireTemplateError(t, Pipe{}.Announce(ctx))
+	})
+	t.Run("chatid not int", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			Env: []string{"CHAT_ID=test"},
+			Announce: config.Announce{
+				Telegram: config.Telegram{
+					MessageTemplate: "test",
+					ChatID:          "{{ .Env.CHAT_ID }}",
+				},
+			},
+		})
+		require.EqualError(t, Pipe{}.Announce(ctx), "telegram: strconv.ParseInt: parsing \"test\": invalid syntax")
 	})
-	require.EqualError(t, Pipe{}.Announce(ctx), `telegram: template: tmpl:1: unexpected "}" in operand`)
 }
 
 func TestAnnounceMissingEnv(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
+		Env: []string{"CHAT_ID=10"},
 		Announce: config.Announce{
-			Telegram: config.Telegram{},
+			Telegram: config.Telegram{
+				ChatID: "{{ .Env.CHAT_ID }}",
+			},
 		},
 	})
 	require.NoError(t, Pipe{}.Default(ctx))
@@ -41,11 +70,11 @@ func TestAnnounceMissingEnv(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Announce: config.Announce{
 				Telegram: config.Telegram{
 					Enabled: true,
