@@ -4,6 +4,7 @@ package archive
 import (
 	"fmt"
 	"io"
+	"os"
 
 	"github.com/goreleaser/goreleaser/pkg/archive/gzip"
 	"github.com/goreleaser/goreleaser/pkg/archive/tar"
@@ -22,16 +23,30 @@ type Archive interface {
 // New archive.
 func New(w io.Writer, format string) (Archive, error) {
 	switch format {
-	case "tar.gz":
+	case "tar.gz", "tgz":
 		return targz.New(w), nil
 	case "tar":
 		return tar.New(w), nil
 	case "gz":
 		return gzip.New(w), nil
-	case "tar.xz":
+	case "tar.xz", "txz":
 		return tarxz.New(w), nil
 	case "zip":
 		return zip.New(w), nil
 	}
 	return nil, fmt.Errorf("invalid archive format: %s", format)
 }
+
+// Copying copies the source archive into a new one, which can be appended at.
+// Source needs to be in the specified format.
+func Copying(r *os.File, w io.Writer, format string) (Archive, error) {
+	switch format {
+	case "tar.gz", "tgz":
+		return targz.Copying(r, w)
+	case "tar":
+		return tar.Copying(r, w)
+	case "zip":
+		return zip.Copying(r, w)
+	}
+	return nil, fmt.Errorf("invalid archive format: %s", format)
+}
